| OlinkAnalyzeVignettes-package | R Documentation |
Exemplifying analysis of large-scale protein data from the 'Olink platform', primarily relative protein expression data that has been exported from 'Olink NPX Software', as well as QUANT data from 'Olink'. QUANT data is log-transformed. Materials focus on reading data, demonstrating data wrangling and quality control analysis, performing statistical analysis and generating figures to visualize the results of the statistical analysis. The goal of this package is to guide users extract biological insights from large-scale protein data run on the 'Olink platform'. More information on 'Olink' data can be found at https://olink.com/.
Maintainer: Kathleen Nevola biostattools@olink.com (ORCID) (kathy-nevola)
Authors:
Kathleen Nevola biostattools@olink.com (ORCID) (kathy-nevola)
Marianne Sandin (ORCID) (marisand)
Jamey Guess (ORCID) (jrguess)
Simon Forsberg (ORCID) (simfor)
Christoffer Cambronero (Orbmac)
Pascal Pucholt (ORCID) (AskPascal)
Boxi Zhang (ORCID) (boxizhang)
Masoumeh Sheikhi (MasoumehSheikhi)
Klev Diamanti (ORCID) (klevdiamanti)
Amrita Kar (amrita-kar)
Lei Conze (leiliuC)
Kristyn Chin (kristynchin-olink)
Danai Topouza (ORCID) (dtopouza)
Stephen Pollo (ORCID) (spollo-olprot)
Kang Dong (ORCID) (KangD-dev)
Other contributors:
Kristian Hodén (ORCID) (kristianHoden) [contributor]
Per Eriksson (ORCID) (b_watcher) [contributor]
Nicola Moloney (ORCID) [contributor]
Britta Lötstedt (ORCID) [contributor]
Emmett Sprecher (ORCID) [contributor]
Jessica Barbagallo (jbarbagallo) [contributor]
Olof Mansson (olofmansson) [contractor]
Ola Caster (OlaCaster) [contributor]
Olink [copyright holder, funder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.